diff -ur PyQt-gpl-5.2/configure.py PyQt-gpl-5.2-nogl/configure.py
--- PyQt-gpl-5.2/configure.py	2014-01-07 20:19:54.000000000 +0400
+++ PyQt-gpl-5.2-nogl/configure.py	2014-02-07 11:21:37.395663471 +0400
@@ -825,6 +825,10 @@
             action='store_true',
             help="disable the building of the Python plugin for qmlscene "
                     "[default: enabled]")
+    g.add_option("--no-opengl", dest='noopengl', default=False,
+            action='store_true',
+            help="disable the building of OpenGL-related stuff "
+                    "[default: enabled]")
     g.add_option("--assume-shared", dest='assumeshared', default=False,
             action='store_true',
             help="assume that the Qt libraries have been built as shared "
@@ -2527,6 +2531,13 @@
     else:
         target_config.from_introspection(opts.verbose, opts.debug)
 
+    if opts.noopengl:
+        inform("OpenGL bindinds are disabled")
+        MODULE_METADATA['QtGui'] = ModuleMetadata(qmake_QT=['gui'])
+        if 'PyQt_OpenGL' not in target_config.qt_disabled_features:
+            error("The '--no-opengl' argument also requires a configuration "
+                    "with 'PyQt_OpenGL' feature disabled.")
+
     target_config.post_configuration()
 
     target_config.override_defaults(opts)
diff -ur PyQt-gpl-5.2/sip/QtCore/QtCoremod.sip PyQt-gpl-5.2-nogl/sip/QtCore/QtCoremod.sip
--- PyQt-gpl-5.2/sip/QtCore/QtCoremod.sip	2014-01-07 20:20:16.000000000 +0400
+++ PyQt-gpl-5.2-nogl/sip/QtCore/QtCoremod.sip	2014-02-07 11:13:04.255664954 +0400
@@ -37,6 +37,7 @@
 %Feature PyQt_PrintPreviewDialog
 %Feature PyQt_RawFont
 %Feature PyQt_Desktop_OpenGL
+%Feature PyQt_OpenGL
 
 %Copying
 Copyright (c) 2014 Riverbank Computing Limited <info@riverbankcomputing.com>
diff -ur PyQt-gpl-5.2/sip/QtGui/qguiapplication.sip PyQt-gpl-5.2-nogl/sip/QtGui/qguiapplication.sip
--- PyQt-gpl-5.2/sip/QtGui/qguiapplication.sip	2014-01-07 20:20:16.000000000 +0400
+++ PyQt-gpl-5.2-nogl/sip/QtGui/qguiapplication.sip	2014-02-07 11:16:52.375664295 +0400
@@ -45,17 +45,25 @@
     #else
         {0, 0, -1, 5},
     #endif
+    #if defined(SIP_FEATURE_PyQt_OpenGL)
         {sipName_QOpenGLContext, &sipType_QOpenGLContext, -1, 6},
+    #else
+        {0, 0, -1, 6},
+    #endif
         {sipName_QSyntaxHighlighter, &sipType_QSyntaxHighlighter, -1, 7},
         {sipName_QScreen, &sipType_QScreen, -1, 8},
-    #if QT_VERSION >= 0x050100
+    #if QT_VERSION >= 0x050100 && defined(SIP_FEATURE_PyQt_OpenGL)
         {sipName_QOpenGLVertexArrayObject, &sipType_QOpenGLVertexArrayObject, -1, 9},
     #else
         {0, 0, -1, 9},
     #endif
         {sipName_QPdfWriter, &sipType_QPdfWriter, -1, 10},
+    #if defined(SIP_FEATURE_PyQt_OpenGL)
         {sipName_QOpenGLContextGroup, &sipType_QOpenGLContextGroup, -1, 11},
-    #if QT_VERSION >= 0x050100
+    #else
+        {0, 0, -1, 11},
+    #endif
+    #if QT_VERSION >= 0x050100 && defined(SIP_FEATURE_PyQt_OpenGL)
         {sipName_QOpenGLDebugLogger, &sipType_QOpenGLDebugLogger, -1, 12},
     #else
         {0, 0, -1, 12},
@@ -68,7 +76,11 @@
         {0, 0, -1, 15},
     #endif
         {sipName_QInputMethod, &sipType_QInputMethod, -1, 16},
+    #if defined(SIP_FEATURE_PyQt_OpenGL)
         {sipName_QOpenGLShaderProgram, &sipType_QOpenGLShaderProgram, -1, 17},
+    #else
+        {0, 0, -1, 17},
+    #endif
         {sipName_QWindow, &sipType_QWindow, -1, 18},
         {sipName_QAbstractTextDocumentLayout, &sipType_QAbstractTextDocumentLayout, -1, 19},
     #if QT_VERSION >= 0x050100 && defined(SIP_FEATURE_PyQt_Desktop_OpenGL)
@@ -79,7 +91,11 @@
         {sipName_QStyleHints, &sipType_QStyleHints, -1, 21},
         {sipName_QTextDocument, &sipType_QTextDocument, -1, 22},
         {sipName_QMovie, &sipType_QMovie, -1, 23},
+    #if defined(SIP_FEATURE_PyQt_OpenGL)
         {sipName_QOpenGLShader, &sipType_QOpenGLShader, -1, 24},
+    #else
+        {0, 0, -1, 24},
+    #endif
         {sipName_QGuiApplication, &sipType_QGuiApplication, -1, -1},
     #if QT_VERSION >= 0x050100
         {sipName_QRegularExpressionValidator, &sipType_QRegularExpressionValidator, -1, 26},
diff -ur PyQt-gpl-5.2/sip/QtGui/qpygui_qpair.sip PyQt-gpl-5.2-nogl/sip/QtGui/qpygui_qpair.sip
--- PyQt-gpl-5.2/sip/QtGui/qpygui_qpair.sip	2014-01-07 20:20:16.000000000 +0400
+++ PyQt-gpl-5.2-nogl/sip/QtGui/qpygui_qpair.sip	2014-02-07 10:58:55.885667407 +0400
@@ -19,6 +19,7 @@
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
 
+%If (PyQt_OpenGL)
 %MappedType QPair<QOpenGLTexture::Filter, QOpenGLTexture::Filter>
         /DocType="tuple-of-QOpenGLTexture.Filter-QOpenGLTexture.Filter"/
 {
@@ -109,7 +110,7 @@
     return sipGetState(sipTransferObj);
 %End
 };
-
+%End
 
 %MappedType QPair<float, float> /DocType="tuple-of-float-float"/
 {
diff -ur PyQt-gpl-5.2/sip/QtGui/QtGuimod.sip PyQt-gpl-5.2-nogl/sip/QtGui/QtGuimod.sip
--- PyQt-gpl-5.2/sip/QtGui/QtGuimod.sip	2014-01-07 20:20:16.000000000 +0400
+++ PyQt-gpl-5.2-nogl/sip/QtGui/QtGuimod.sip	2014-02-07 10:46:58.875669480 +0400
@@ -45,7 +45,9 @@
 
 %DefaultSupertype sip.simplewrapper
 
+%If (PyQt_OpenGL)
 %Include opengl_types.sip
+%End
 
 %Include qabstracttextdocumentlayout.sip
 %Include qbackingstore.sip
@@ -75,6 +77,7 @@
 %Include qmatrix4x4.sip
 %Include qmovie.sip
 %Include qoffscreensurface.sip
+%If (PyQt_OpenGL)
 %Include qopenglbuffer.sip
 %Include qopenglcontext.sip
 %Include qopengldebug.sip
@@ -86,6 +89,7 @@
 %Include qopengltimerquery.sip
 %Include qopenglversionfunctions.sip
 %Include qopenglvertexarrayobject.sip
+%End
 %Include qpagedpaintdevice.sip
 %Include qpainter.sip
 %Include qpaintdevice.sip
@@ -128,7 +132,9 @@
 %Include qvector4d.sip
 %Include qwindow.sip
 %Include qwindowdefs.sip
+%If (PyQt_OpenGL)
 %Include opengl_types.sip
+%End
 %Include qpygui_qlist.sip
 %Include qpygui_qpair.sip
 %Include qpygui_qvector.sip
